@@ -1,15 +1,17 @@
-# @(#)$Ident: URL.pm 2013-07-29 15:53 pjf ;
-
 package Data::Validation::Constraints::URL;
 
 use namespace:sweep;
-use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
+use Data::Validation::Constants;
 use LWP::UserAgent;
 
 extends q(Data::Validation::Constraints);
 
+EXCEPTION_CLASS->add_exception( 'ValidURL', {
+   parents => [ 'Constraint' ],
+   error   => 'Parameter [_1] value [_2] is not a valid URL' } );
+
 around '_validate' => sub {
    my ($orig, $self, $val) = @_; my $ua = LWP::UserAgent->new();
 
